Code repository & Versions
=================

DoWhy is hosted on GitHub.

You can browse the code in a html-friendly format `here
<https://github.com/Microsoft/dowhy>`_.

Version 0.2-alpha (WIP)
-----------------------
This version includes breaking changes.

* The CausalModel import is now simpler. `from dowhy import CausalModel`.
* do_why.py is renamed to causal_model.py.  This should not change any external
  usage.

Version 0.1.1-alpha
-------------------
This is the first release of the library.
